@@ -16,9 +16,9 @@
   packageStartupMessage("** maotai")
   packageStartupMessage("**  - Tools for Matrix Algebra, Optimization and Inference Problems")
   packageStartupMessage("**")
-  packageStartupMessage("** Version    : ",this.version,"       (",this.year,")",sep="")
-  packageStartupMessage("** Maintainer : Kisung You  (kisungyou@outlook.com)")
-  packageStartupMessage("** Website    : https://kisungyou.com/maotai")
+  packageStartupMessage("** Version    : ",this.version,"      (",this.year,")",sep="")
+  packageStartupMessage("** Maintainer : Kisung You (kisungyou@outlook.com)")
+  packageStartupMessage("** Website    : https://www.kisungyou.com/maotai")
   packageStartupMessage("**")
   packageStartupMessage("** Please share any bugs or suggestions to the maintainer.")
   packageStartupMessage("**-----------------------------------------------------------------**")
